package ij.process;

/** RGB image statistics, including histogram. */
public class ColorStatistics extends ImageStatistics {

	/** Construct an ImageStatistics object from a ColorProcessor
		using the standard measurement options (area, mean,
		mode, min and max) and generating a 256 bin histogram. */
	public ColorStatistics(ImageProcessor ip) {
		this(ip, AREA+MEAN+MODE+MIN_MAX, 256);
	}

	/** Constructs a ColorStatistics object from a ColorProcessor using
		the specified measurement options and number of histogram bins.
		The number of bins is currently fixed at 256. */
	public ColorStatistics(ImageProcessor ip, int mOptions, int nBins) {
		ColorProcessor cp = (ColorProcessor)ip;
		histogram = cp.getHistogram();
		setRoiLimits(ip);
		getStatistics(0,255);
		if ((mOptions&MIN_MAX)!=0)
			getMinAndMax();
		if ((mOptions&CENTROID)!=0)
			getCentroid(ip);
	}

}